@@ -33,9 +33,15 @@ class ConfigCommand:
         Set full_name and email for reuse in any project created further on.
         """
         ConfigCommand.check_ct_config_dir_exists()
-        full_name = mlf_core_questionary_or_dot_mlf_core('text', 'Full name', default='Homer Simpson')
-        email = mlf_core_questionary_or_dot_mlf_core('text', 'Personal or work email', default='homer.simpson@example.com')
-        github_username = mlf_core_questionary_or_dot_mlf_core('text', 'Github username', default='HomerGithub')
+        full_name = mlf_core_questionary_or_dot_mlf_core(function='text',
+                                                         question='Full name',
+                                                         default='Homer Simpson')
+        email = mlf_core_questionary_or_dot_mlf_core(function='text',
+                                                     question='Personal or work email',
+                                                     default='homer.simpson@example.com')
+        github_username = mlf_core_questionary_or_dot_mlf_core(function='text',
+                                                               question='Github username',
+                                                               default='HomerGithub')
 
         # if the configs exist, just update them
         if os.path.exists(ConfigCommand.CONF_FILE_PATH):
@@ -66,26 +72,28 @@ class ConfigCommand:
             yaml = YAML()
             settings = yaml.load(path)
             if not all(attr in settings for attr in ['full_name', 'github_username', 'email']):
-                print('[bold red]The mlf_core config file misses some required attributes!')
+                print('[bold red]The mlf-core config file misses some required attributes!')
                 print('[bold blue]Lets set them before setting your Github personal access token!')
                 ConfigCommand.config_general_settings()
 
         except FileNotFoundError:
-            print('[bold red]Cannot find a mlf_core config file. Is this your first time using mlf-core?')
+            print('[bold red]Cannot find a mlf-core config file. Is this your first time using mlf-core?')
             print('[bold blue]Lets create one before setting your Github personal access token!')
             ConfigCommand.config_general_settings()
 
-        if mlf_core_questionary_or_dot_mlf_core('confirm',
-                                                'Do you want to configure your GitHub personal access token right now?\n'
+        if mlf_core_questionary_or_dot_mlf_core(function='confirm',
+                                                question='Do you want to configure your GitHub personal access token right now?\n'
                                                 'You can still configure it later '
                                                 'by calling    mlf-core config pat',
                                                 default='Yes'):
-            access_token = mlf_core_questionary_or_dot_mlf_core('password', 'Please enter your Github Access token')
+            access_token = mlf_core_questionary_or_dot_mlf_core(function='password',
+                                                                question='Please enter your Github Access token')
             access_token_b = access_token.encode('utf-8')
 
             # ask for confirmation since this action will delete the PAT irrevocably if the user has not saved it anywhere else
-            if not mlf_core_questionary_or_dot_mlf_core('confirm', 'You´re about to update your personal access token. This action cannot be undone!\n'
-                                                                   'Do you really want to continue?',
+            if not mlf_core_questionary_or_dot_mlf_core(function='confirm',
+                                                        question='You´re about to update your personal access token. This action cannot be undone!\n'
+                                                                 'Do you really want to continue?',
                                                         default='Yes'):
                 sys.exit(1)
 
